@@ -11,28 +11,28 @@ from plugins.generic.enumeration import Enumeration as GenericEnumeration
 class Enumeration(GenericEnumeration):
     def getPasswordHashes(self):
         warnMsg = "on MonetDB it is not possible to enumerate password hashes"
-        logger.warn(warnMsg)
+        logger.warning(warnMsg)
 
         return {}
 
     def getStatements(self):
         warnMsg = "on MonetDB it is not possible to enumerate the SQL statements"
-        logger.warn(warnMsg)
+        logger.warning(warnMsg)
 
         return []
 
     def getPrivileges(self, *args, **kwargs):
         warnMsg = "on MonetDB it is not possible to enumerate the user privileges"
-        logger.warn(warnMsg)
+        logger.warning(warnMsg)
 
         return {}
 
     def getRoles(self, *args, **kwargs):
         warnMsg = "on MonetDB it is not possible to enumerate the user roles"
-        logger.warn(warnMsg)
+        logger.warning(warnMsg)
 
         return {}
 
     def getHostname(self):
         warnMsg = "on MonetDB it is not possible to enumerate the hostname"
-        logger.warn(warnMsg)
+        logger.warning(warnMsg)
